#!/bin/bash

# Check if the repository name is provided as an argument
if [ -z "$1" ]; then
    echo "Usage: $0 <repository-name>"
    exit 1
fi

REPO_NAME=$1
REPO1="https://huggingface.co/mradermacher/${REPO_NAME}-GGUF"
REPO2="https://huggingface.co/mradermacher/${REPO_NAME}-i1-GGUF"
OUTPUT_FILE="${REPO_NAME}.yaml"

# Clone the repositories with GIT_LFS_SKIP_SMUDGE=1
GIT_LFS_SKIP_SMUDGE=1 git clone $REPO1
GIT_LFS_SKIP_SMUDGE=1 git clone $REPO2

# Declare an associative array to store the total sizes
declare -A sizes

# Function to process the repository
process_repo() {
    local repo_dir=$1
    cd $repo_dir

    # Read the input line by line
    while read -r line; do
        # Check if the line contains a filepath
        if [[ $line == filepath:* ]]; then
            # Handle files that are not split into parts
            if [[ $line == *".part"* ]]; then
                part_name=$(echo $line | awk '{print $2}' | awk -F'.' '{print $(NF-2)}')
            else
                part_name=$(echo $line | awk '{print $2}' | awk -F'.' '{print $(NF-1)}')
            fi
        fi

        # Check if the line contains a size
        if [[ $line == size:* ]]; then
            # Extract the size value
            size=$(echo $line | awk '{print $2}')

            # Add the size to the corresponding total in the associative array
            sizes[$part_name]=$((sizes[$part_name] + size))
        fi
    done < <(git lfs ls-files -s --debug)

    cd ..
    rm -rf $repo_dir
}

# Process each cloned repository
process_repo "${REPO_NAME}-GGUF"
process_repo "${REPO_NAME}-i1-GGUF"

# Output the results to a YAML file, excluding "imatrix.dat" and sorting by size
{
    for part_name in "${!sizes[@]}"; do
        if [[ $part_name != "imatrix" ]]; then
            echo "$part_name: ${sizes[$part_name]}"
        fi
    done | sort -t: -k2 -n
} > $OUTPUT_FILE

echo "Results stored in $OUTPUT_FILE"
nano $OUTPUT_FILE
